|pipeline status| |coverage report| |version|

bilby_pipe
==========

A package for automating transient gravitational wave parameter estimation

-  `Installation
   instructions <https://lscsoft.docs.ligo.org/bilby_pipe/installation.html>`__
-  `Documentation <https://lscsoft.docs.ligo.org/bilby_pipe/index.html>`__
-  `Issue tracker <https://git.ligo.org/lscsoft/bilby/issues>`__


.. |pipeline status| image:: https://git.ligo.org/lscsoft/bilby_pipe/badges/master/pipeline.svg
   :target: https://git.ligo.org/lscsoft/bilby_pipe/commits/master
.. |coverage report| image:: https://lscsoft.docs.ligo.org/bilby_pipe/coverage_badge.svg
   :target: https://lscsoft.docs.ligo.org/bilby_pipe/htmlcov/
.. |version| image:: https://img.shields.io/pypi/pyversions/bilby-pipe.svg

